@@ -10,20 +10,39 @@ ApplicationsWindow::ApplicationsWindow(QWidget *parent, QStringList files) :
 
     ui->applicationList->setItemDelegate(new DescriptiveDelegate(this));
 
-    if (!files.isEmpty()) {
-        this->files = files;
-        ui->windowMenu->removeAction(ui->addAction);
-        ui->windowMenu->removeAction(ui->clearAction);
-        connect(ui->applicationList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onItemActivated(QListWidgetItem*)));
-    } else {
+    if (files.isEmpty()) {
+        // Removing the existing menu bar doesn't seem to work properly, so create and add the menu only if necessary
+        QMenuBar *menuBar = new QMenuBar(this);
+        QMenu *windowMenu = new QMenu(menuBar);
+        windowMenu->addAction(ui->addAction);
+        windowMenu->addAction(ui->clearAction);
+        menuBar->addAction(windowMenu->menuAction());
+        this->setMenuBar(menuBar);
+
         connect(ui->applicationList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(editCurrentApplication()));
         connect(ui->applicationList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showApplicationMenu(QPoint)));
         connect(ui->addAction, SIGNAL(triggered()), this, SLOT(onAddClicked()));
         connect(ui->clearAction, SIGNAL(triggered()), this, SLOT(onClearClicked()));
+    } else {
+        this->files = files;
+        connect(ui->applicationList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onItemActivated(QListWidgetItem*)));
     }
 
     connect(new QShortcut(QKeySequence(Qt::Key_Backspace), this), SIGNAL(activated()), this, SLOT(close()));
 
+    // Create some example entries
+    if (!QSettings().contains("Applications/Names")) {
+        QSettings().setValue("Applications/Names",
+                             QStringList()
+                             << "Notes"
+                             << "Terminal (current dir)");
+
+        QSettings().setValue("Applications/Commands",
+                             QStringList()
+                             << "osso_notes %s"
+                             << "osso-xterm \"sh -c 'cd \"\"\"$(dirname \"\"%s\"\")\"\"\"; sh'\"");
+    }
+
     QStringList names = QSettings().value("Applications/Names").toStringList();
     QStringList commands = QSettings().value("Applications/Commands").toStringList();
 
@@ -33,6 +52,8 @@ ApplicationsWindow::ApplicationsWindow(QWidget *parent, QStringList files) :
         item->setData(DescriptiveDelegate::DescriptionRole, commands.at(i));
         ui->applicationList->addItem(item);
     }
+
+    updateVisibility();
 }
 
 ApplicationsWindow::~ApplicationsWindow()
