@@ -1,5 +1,10 @@
 #include "filelistview.h"
 
+// Item sizes
+#define GRID_WIDTH 142
+#define GRID_HEIGHT 80
+#define LIST_HEIGHT 70
+
 FileListView::FileListView(QWidget *parent) :
     QListView(parent)
 {
@@ -8,11 +13,14 @@ FileListView::FileListView(QWidget *parent) :
     this->setMovement(QListView::Static);
 
     enableGridMode(false);
+    savedPosition = 0;
 
     // Initialize the model
     filesystemModel = new FileSystemModel(this);
     this->setModel(filesystemModel);
 
+    connect(filesystemModel, SIGNAL(loadingStarted()), this, SLOT(onLoadingStarted()));
+    connect(filesystemModel, SIGNAL(loadingFinished()), this, SLOT(onLoadingFinished()));
     connect(this, SIGNAL(activated(QModelIndex)), this, SLOT(onActivated(QModelIndex)));
 }
 
@@ -45,14 +53,22 @@ void FileListView::keyPressEvent(QKeyEvent *e)
 
 void FileListView::enableGridMode(bool enable)
 {
+    int convertedPosition = 0;
+
     if (enable) {
+        if (this->viewMode() == QListView::ListMode)
+            convertedPosition = toGridPosition(this->verticalScrollBar()->value());
+
         this->itemDelegate()->deleteLater();
         this->setItemDelegate(new GridDelegate(this));
 
         this->setViewMode(QListView::IconMode);
-        this->setGridSize(QSize(142,80));
+        this->setGridSize(QSize(GRID_WIDTH, GRID_HEIGHT));
         this->setFlow(QListView::LeftToRight);
     } else {
+        if (this->viewMode() == QListView::IconMode)
+            convertedPosition = fromGridPosition(this->verticalScrollBar()->value());
+
         this->itemDelegate()->deleteLater();
         this->setItemDelegate(new DetailedDelegate(this));
 
@@ -60,6 +76,27 @@ void FileListView::enableGridMode(bool enable)
         this->setGridSize(QSize());
         this->setFlow(QListView::TopToBottom);
     }
+
+    if (convertedPosition) {
+        // Wait for the list to be resized
+        QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
+
+        this->verticalScrollBar()->setValue(convertedPosition);
+    }
+}
+
+int FileListView::toGridPosition(int listPosition)
+{
+    return listPosition
+         * ((double) GRID_HEIGHT / LIST_HEIGHT)
+         / (this->width() / GRID_WIDTH); // items per row
+}
+
+int FileListView::fromGridPosition(int gridPosition)
+{
+    return gridPosition
+         * ((double) LIST_HEIGHT / GRID_HEIGHT)
+         * (this->width() / GRID_WIDTH); // items per row
 }
 
 void FileListView::resizeEvent(QResizeEvent *e)
@@ -70,7 +107,31 @@ void FileListView::resizeEvent(QResizeEvent *e)
 
 void FileListView::onActivated(QModelIndex index)
 {
-    openPath(index.data(FileSystemModel::PathRole).toString());
+    QString path = index.data(FileSystemModel::PathRole).toString();
+
+    if (!path.endsWith("..")) savedPosition = -1; // ignore the saved position
+    openPath(path);
+}
+
+void FileListView::onLoadingStarted()
+{
+    savedPosition = this->viewMode() == QListView::IconMode ?
+                    fromGridPosition(this->verticalScrollBar()->value()) :
+                    this->verticalScrollBar()->value();
+
+    emit loadingStarted();
+}
+
+void FileListView::onLoadingFinished()
+{
+    // Wait for the list to be resized
+    QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
+
+    this->verticalScrollBar()->setValue(this->viewMode() == QListView::IconMode ?
+                                        toGridPosition(savedPosition) :
+                                        savedPosition);
+
+    emit loadingFinished();
 }
 
 QString FileListView::currentPath()
@@ -83,6 +144,11 @@ void FileListView::setDetails(FileSystemModel::Detail firstDetail, FileSystemMod
     filesystemModel->setDetails(firstDetail, secondDetail);
 }
 
+void FileListView::setSavedPosition(int savedPosition)
+{
+    this->savedPosition = this->savedPosition == -1 ? 0 : savedPosition;
+}
+
 void FileListView::openPath(QString path)
 {
     if (!path.startsWith("/"))
@@ -91,10 +157,19 @@ void FileListView::openPath(QString path)
     QFileInfo file(path);
     path = file.absoluteFilePath();
 
+    if (!file.exists()) {
+        qDebug() << "File does not exist" << path;
+        return;
+    }
+
     if (file.isDir()) {
         qDebug() << "Changing directory" << path;
+
         filesystemModel->setLocation(path);
-        emit locationChanged(path);
+
+        emit locationChanged(path, this->viewMode() == QListView::IconMode ?
+                                   fromGridPosition(this->verticalScrollBar()->value()) :
+                                   this->verticalScrollBar()->value());
 
         this->clearSelection();
         this->scrollToTop();
@@ -147,9 +222,10 @@ void FileListView::enableMultiSelection(bool enable)
     } else {
         this->setSelectionMode(QAbstractItemView::SingleSelection);
         this->setSelectionRectVisible(false);
-        this->clearSelection();
         connect(this, SIGNAL(activated(QModelIndex)), this, SLOT(onActivated(QModelIndex)), Qt::UniqueConnection);
     }
+
+    this->clearSelection();
 }
 
 void FileListView::sortByName()
