@@ -37,7 +37,7 @@ void FileOperation::run()
     reportState(Preparing);
 
     // Exapnd the simple source list to a list which contains all files and directories
-    QList<FileJob> expansionQueue;
+    QList<FileJob> expansionStack;
     totalSize = 1; // Prevent division by zero
 
     // Create an initial list for further expansion
@@ -45,13 +45,13 @@ void FileOperation::run()
         FileJob job;
         job.source = files.at(i).absoluteFilePath();
         job.target = targetDir.absoluteFilePath() + '/' + files.at(i).fileName();
-        expansionQueue.append(job);
+        expansionStack.prepend(job);
     }
 
     // Expand the item list to create an index of all files and directories
-    while (!expansionQueue.isEmpty()) {
+    while (!expansionStack.isEmpty()) {
         // Take one of the jobs to expand
-        FileJob job = expansionQueue.takeFirst();
+        FileJob job = expansionStack.takeFirst();
         QFileInfo sourceInfo(job.source);
 
         if (sourceInfo.isSymLink()) {
@@ -69,7 +69,7 @@ void FileOperation::run()
                 FileJob subJob;
                 subJob.source = job.source + '/' + entry;
                 subJob.target = job.target + '/' + entry;
-                expansionQueue.append(subJob);
+                expansionStack.prepend(subJob);
             }
         }
 
