@@ -60,6 +60,10 @@ public:
     static QString sizeString(qint64 size);
     static QString detailString(QFileInfo info, Detail detail);
 
+signals:
+    void loadingStarted();
+    void loadingFinished();
+
 private:
     QStandardItemModel *model;
     QFileSystemWatcher *watcher;
