@@ -16,6 +16,7 @@
 #include <QApplication>
 #include <QHBoxLayout>
 #include <QStringList>
+#include <QList>
 
 class LocationWidget : public QScrollArea
 {
@@ -25,7 +26,7 @@ public:
     LocationWidget(QWidget *parent);
     ~LocationWidget();
 
-    void setLocation(QString path);
+    int setLocation(QString path, int oldPosition);
     bool isEditorEnabled();
 
 public slots:
@@ -49,6 +50,8 @@ private:
 
     QString currentPath;
 
+    QList<int> scrollPositions;
+
 private slots:
     void onButtonClicked();
 };
