@@ -112,18 +112,26 @@ MainWindow::MainWindow(QFileInfo startingLocation) :
     // Should be called before setting the initial location, to avoid unnecessary file listings
     reloadSettings();
 
-    // TODO: fix nonexistent default location
-    if (startingLocation.exists()) {
-        // Prepare the initial view for the requested location
-        ui->browserList->openPath(startingLocation.isDir() ? startingLocation.absoluteFilePath() : startingLocation.absolutePath());
-    } else {
-        // Prepare the default initial view
-        ui->browserList->openPath(QSettings().value("Main/StartingLocation", DEFAULT_StartingLocation).toString());
-
-        // Start in bookmarks if configured to do so
-        if (QSettings().value("Main/StartInBookmarks", DEFAULT_StartInBookmarks).toBool())
-            showBookmarks();
+    // Determine location for the initial view
+    if (!startingLocation.exists() || !startingLocation.isDir()) {
+        // Recover from invalid location in the argument
+        startingLocation = QSettings().value("Main/StartingLocation", DEFAULT_StartingLocation).toString();
+        if (!startingLocation.exists() || !startingLocation.isDir()) {
+            // Recover from invalid location in the settings
+            startingLocation = QFileInfo(DEFAULT_StartingLocation);
+            if (!startingLocation.exists() || !startingLocation.isDir()) {
+                // Recover from invalid default location
+                startingLocation = QFileInfo("/");
+            }
+        }
     }
+
+    // Prepare the initial view
+    ui->browserList->openPath(startingLocation.absoluteFilePath());
+
+    // Start in bookmarks if configured to do so
+    if (QSettings().value("Main/StartInBookmarks", DEFAULT_StartInBookmarks).toBool())
+        showBookmarks();
 }
 
 MainWindow::~MainWindow()
@@ -132,6 +140,9 @@ MainWindow::~MainWindow()
     QSettings().setValue("Browser/GridView", ui->gridAction->isChecked());
     QSettings().setValue("Browser/ShowHidden", ui->hiddenAction->isChecked());
 
+    if (QSettings().value("Main/SaveLocation", DEFAULT_SaveLocation).toBool())
+        QSettings().setValue("Main/StartingLocation", ui->browserList->currentPath());
+
     delete Clipboard::get();
 
     delete ui;
