@@ -48,9 +48,11 @@ private:
 
 private slots:
     void onOrientationChanged(int w, int h);
-    void onLocationChanged(QString path);
-    void enableFullscreen(bool enable);
+    void onLocationChanged(QString path, int oldPosition);
+    void onLoadingStarted();
+    void onLoadingFinished();
 
+    void enableFullscreen(bool enable);
     void reloadSettings();
 
     void showSettings();
