@@ -29,6 +29,7 @@ void SettingsWindow::load()
 {
     ui->startingLocationButton->setValueText(QSettings().value("Main/StartingLocation", DEFAULT_StartingLocation).toString());
 
+    ui->saveLocationBox->setChecked(QSettings().value("Main/SaveLocation", DEFAULT_SaveLocation).toBool());
     ui->startInBookmarksBox->setChecked(QSettings().value("Main/StartInBookmarks", DEFAULT_StartInBookmarks).toBool());
     ui->runAsRootBox->setChecked(QSettings().value("Main/RunAsRoot", DEFAULT_RunAsRoot).toBool());
 
@@ -89,6 +90,7 @@ void SettingsWindow::save()
 {
     QSettings().setValue("Main/StartingLocation", ui->startingLocationButton->valueText());
 
+    QSettings().setValue("Main/SaveLocation", ui->saveLocationBox->isChecked());
     QSettings().setValue("Main/StartInBookmarks", ui->startInBookmarksBox->isChecked());
     QSettings().setValue("Main/RunAsRoot", ui->runAsRootBox->isChecked());
 
